
List of operators
===================

This document is automatically generated, and contains the operators that Janis
provides. They are split up by section (Regular operators, Logical operators, Standard library) with
the relevant Python import.

For more information about expressions and operators, visit `Expressions in Janis <https://janis.readthedocs.io/en/latest/references/expressions.html>`_.


Regular operators
+++++++++++++++++

Import with: ``from janis_core.operators.operator import *``





- **IndexOperator**: ``Array[X], Int -> X``





- **AsStringOperator**: ``X -> String``





- **AsBoolOperator**: ``X -> Boolean``





- **AsIntOperator**: ``X -> Int``





- **AsFloatOperator**: ``X -> Float``





Logical operators
+++++++++++++++++

Import with: ``from janis_core.operators.logical import *``





- **IsDefined**: ``Any? -> Boolean``





- **If**: ``(condition: Boolean, value_if_true: X, value_if_false: Y) -> Union[X,Y]``





- **NotOperator**: ``Boolean -> Boolean``





- **AndOperator**: ``Boolean, Boolean -> Boolean``





- **OrOperator**: ``Boolean, Boolean -> Boolean``





- **EqualityOperator**: ``Any, Any -> Boolean``





- **InequalityOperator**: ``Any, Any -> Boolean``





- **GtOperator**: ``Comparable, Comparable -> Boolean``





- **GteOperator**: ``Comparable, Comparable -> Boolean``





- **LtOperator**: ``Comparable, Comparable -> Boolean``





- **LteOperator**: ``Comparable, Comparable -> Boolean``





- **AddOperator**: ``Any, Any -> Any``





- **SubtractOperator**: ``NumericType, NumericType -> NumericType``





- **MultiplyOperator**: ``Numeric, NumericType -> NumericType``





- **DivideOperator**: ``Numeric, NumericType -> NumericType``





- **FloorOperator**: ``Numeric, NumericType -> Int``





- **CeilOperator**: ``Numeric, NumericType -> Int``





- **RoundOperator**: ``Numeric, NumericType -> Int``





Standard library
++++++++++++++++

Import with: ``from janis_core.operators.standard import *``





- **ReadContents**: ``File -> String``





- **JoinOperator**: ``Array[X], String -> String``





- **BasenameOperator**: ``Union[File, Directory] -> String``





- **TransformOperator**: ``Array[Array[X]] -> Array[Array[x]]``





- **LengthOperator**: ``Array[X] -> Int``





- **FlattenOperator**: ``Array[Array[X]] -> Array[x]``





- **ApplyPrefixOperator**: ``String, Array[String] -> String``





- **FileSizeOperator**: ``File -> Float``


    Returned in MB: Note that this does NOT include the reference files (yet)
    



- **FirstOperator**: ``Array[X?] -> X``





- **FilterNullOperator**: ``Array[X?] -> Array[X]``





*This page was autogenerated.*
